# Avocado

[![Build Status](https://travis-ci.org/cbmi/avocado.png?branch=2.2)](https://travis-ci.org/cbmi/avocado) [![Coverage Status](https://coveralls.io/repos/cbmi/avocado/badge.png?branch=2.2)](https://coveralls.io/r/cbmi/avocado?branch=2.1) [![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/cbmi/avocado/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

Documentation at http://avocado.harvest.io
